@@ -1,9 +1,10 @@
 from config import Config, ConfigError
-from lib import find, with_line_numbers
+from lib import find, version, with_line_numbers
 from split import Split
 
 __all__ = (
     'Config',
     'ConfigError',
-    'Split'
+    'Split',
+    'version'
 )
